------------
Installation
------------

| **Cookiecutter Python Package** is available directly as source code on github, but also being a Python Package Generator/Template,
| available on pypi too.


Get Code from Github
--------------------

.. code-block:: shell

  git clone git@github.com:boromir674/cookiecutter-python-package.git


Install PyPI package (in current environment)
---------------------------------------------

.. code-block:: shell

  python3 -m pip install cookiecutter-python
